@@ -11,6 +11,23 @@ metric <- function(){
   return(obj)
 }
 
+#'@title Accuracy Calculator
+#'@description Class for accuracy calculation
+#'@return Metric object
+#'@examples
+#'# See ?mt_accuracy for an example of Accuracy Calculator
+#'@export
+mt_accuracy <- function(){
+  obj <- metric()
+  class(obj) <- append("mt_accuracy", class(obj))
+  return(obj)
+}
+
+#'@export
+evaluate.mt_accuracy <- function(obj, y_pred, y_true, ...){
+  return(mean(y_pred==y_true, na.rm=TRUE))
+}
+
 #'@title Precision Calculator
 #'@description Class for precision calculation
 #'@return Metric object
@@ -25,7 +42,7 @@ mt_precision <- function(){
 
 #'@export
 evaluate.mt_precision <- function(obj, y_pred, y_true, ...){
-  return(mean(y_pred[y_true==TRUE], na.rm=TRUE))
+  return(mean(y_true[y_pred==TRUE], na.rm=TRUE))
 }
 
 #'@title Recall Calculator
@@ -42,7 +59,7 @@ mt_recall <- function() {
 
 #'@export
 evaluate.mt_recall <- function(obj, y_pred, y_true, ...){
-  return(mean(y_true[y_pred==TRUE] == TRUE, na.rm=TRUE))
+  return(mean(y_pred[(y_true==TRUE)], na.rm=TRUE))
 }
 
 #'@title FScore Calculator
@@ -50,7 +67,7 @@ evaluate.mt_recall <- function(obj, y_pred, y_true, ...){
 #'@param f The F parameter for the F-Score metric
 #'@return Metric object
 #'@examples
-#'# See ?mt_precision for an example of FScore Calculator
+#'# See ?mt_fscore for an example of FScore Calculator
 #'@export
 mt_fscore <- function(f=1) {
   obj <- metric()
@@ -64,7 +81,33 @@ evaluate.mt_fscore <- function(obj, y_pred, y_true, ...){
   precision <- evaluate(mt_precision(), y_pred, y_true)
   recall <- evaluate(mt_recall(), y_pred, y_true)
   
-  fscore <- (2* precision * recall) / (precision + recall)
+  fscore <- (2 * (precision * recall)) / (precision + recall)
   
   return(fscore)
+}
+
+#'@title ROC AUC Calculator
+#'@description Class for QOC AUC calculation
+#'@return Metric object
+#'@examples
+#'# See ?mt_rocauc for an example of ROC AUC Calculator
+#'@export
+mt_rocauc <- function() {
+  obj <- metric()
+  class(obj) <- append("mt_rocauc", class(obj))
+  return(obj)
+}
+
+#'@importFrom pROC auc
+#'@export
+evaluate.mt_rocauc <- function(obj, y_pred, y_true, ...){
+  y_pred[is.na(y_pred)] <- FALSE
+  
+  if((sum(as.numeric(unlist(y_pred))-1) == 0) | (sum(as.numeric(unlist(y_true))-1) == 0)){
+    return(0)
+  }else{
+    rocauc <- pROC::auc(pROC::roc(y_true, y_pred, levels=levels(y_true), direction='<'))
+    
+    return(rocauc)
+  }
 }
\ No newline at end of file
