@@ -10,30 +10,29 @@
 #'library(daltoolbox)
 #'library(heimdall)
 #'
-#'# This example assumes a model residual where 1 is an error and 0 is a correct prediction.
+#'# This example uses an error-based drift detector with a synthetic a 
+#'# model residual where 1 is an error and 0 is a correct prediction.
 #'
 #'data(st_drift_examples)
 #'data <- st_drift_examples$univariate
 #'data$event <- NULL
 #'data$prediction <- st_drift_examples$univariate$serie > 4
 #'
-#'
 #'model <- dfr_hddm()
 #'
-#'detection <- c()
-#'output <- list(obj=model, pred=FALSE)
-#'for (i in 1:length(data$serie)){
-#'  output <- update_state(output$obj, data$serie[i])
-#'  if (output$pred){
+#'detection <- NULL
+#'output <- list(obj=model, drift=FALSE)
+#'for (i in 1:length(data$prediction)){
+#'  output <- update_state(output$obj, data$prediction[i])
+#'  if (output$drift){
 #'    type <- 'drift'
 #'    output$obj <- reset_state(output$obj)
 #'  }else{
 #'    type <- ''
 #'  }
-#'  detection <- rbind(detection, list(idx=i, event=output$pred, type=type))
+#'  detection <- rbind(detection, data.frame(idx=i, event=output$drift, type=type))
 #'}
 #'
-#'detection <- as.data.frame(detection)
 #'detection[detection$type == 'drift',]
 #'@export
 dfr_hddm <- function(drift_confidence=0.001, warning_confidence=0.005, two_side_option=TRUE) {
@@ -148,7 +147,7 @@ update_state.dfr_hddm <- function(obj, value){
 
   obj$state <- state
   
-  return(list(obj=obj, pred=obj$drifted))
+  return(list(obj=obj, drift=obj$drifted))
 }
 
 #'@export
